@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.5.4   2008/05/10
+ * Version: 1.6.1   2008/05/10
  *
  */
 #include <errno.h>
@@ -37,6 +37,7 @@ struct module;
 #include <asm/byteorder.h>
 #include <linux/ip.h>
 #include <sched.h>
+#include <sys/ptrace.h>
 
 #ifndef __NR_sys_kexec_load
 #ifdef __NR_kexec_load
@@ -133,6 +134,8 @@ static void ClearStatus(void) {
 		}
 		write(status_fd, "=0\n", 3);
 	}
+	snprintf(buffer, sizeof(buffer) - 1, "255-ALLOW_ENFORCE_GRACE=1\n");
+	write(status_fd, buffer, strlen(buffer));
 	fclose(fp);
 }
 
